<template>
  <div class="tree-table-container">
    <div class="drag-box" ref="drag-box">
      <div class="drag-left">
        <div class="common-tree-container">
          <div class="common-tree-title">
            <i class="el-icon-menu"></i> 单位管理目录
          </div>
          <div class="common-tree-content">
            <!-- :render-content="renderContent" -->
            <el-tree highlight-current v-if="treeData.length" :data="treeData" :props="defaultProps"
              @node-click="handleNodeClick" default-expand-all>
            </el-tree>
          </div>
        </div>
      </div>
      <div class="drag-resize" title="收缩侧边栏">
        ⋮
      </div>
      <div class="drag-mid">
        <div class="common-table-container">
          <div class="bbsl-common-page">
            <div class="bbsl-table-search">
              <el-form v-model="queryParam" label-width="auto">
                <el-row :gutter="10">
                  <el-col :span="6">
                    <el-form-item label="人员名称">
                      <el-input maxlength="64" clearable placeholder="请输入人员名称" v-model="querys[0].value">
                      </el-input>
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="人员类型">
                      <el-select clearable v-model="querys[2].value" placeholder="请选择人员类型">
                        <el-option v-for="item in types" :key="item.value" :label="item.name"
                          :value="item.value"></el-option>
                      </el-select>
                    </el-form-item>
                  </el-col>
                  <el-col :span="4">
                    <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索
                    </el-button>
                    <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
                  </el-col>
                </el-row>
              </el-form>
            </div>
            <div class="bbsl-table-content" ref="contentPanel">
              <div class="bbsl-btn-content" ref="btnPanel">
                <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
                <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
                  <el-button slot="reference" :disabled="!multipleSelection.length" type="danger" icon="el-icon-delete"
                    style="margin-left: 10px">删除
                  </el-button>
                </el-popconfirm>
              </div>
              <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
                <el-table-column type="selection" width="55"></el-table-column>
                <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
                <el-table-column min-width="80" prop="name" label="人员名称" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="80" prop="type" label="人员类型" show-overflow-tooltip>
                  <template slot-scope="scope">
                    <div>
                      {{
                        scope.row.type == 1
                          ? '管理人员'
                          : scope.row.type == 2
                            ? '建设人员'
                            : '运维人员'
                      }}
                    </div>
                  </template>
                </el-table-column>
                <el-table-column min-width="80" prop="code" label="人员编码" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="80" prop="companyName" label="所属单位" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="120" prop="mobile" label="联系电话" show-overflow-tooltip>
                </el-table-column>
                <!-- <el-table-column prop="tel" label="联系方式" show-overflow-tooltip>
                </el-table-column> -->
                <el-table-column prop="address" label="住址" min-width="150" show-overflow-tooltip></el-table-column>
                <el-table-column min-width="150" prop="memo" label="备注" show-overflow-tooltip></el-table-column>
              </el-table>
              <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
                @size-change="handleSizeChange" @current-change="handleCurrentChange"
                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                :total="total"></el-pagination>
            </div>
          </div>
        </div>
      </div>
    </div>
    <userManageDialog @reload="reload" ref="formModal"></userManageDialog>
    <userOrgDialog v-if="showFormDias" :pId="pId" :showFormDias="showFormDias" @refList="getTreen"
      @closeFormDiaos="closeFormDiaos" :titles="titles" />
    <!-- 修改组织弹框 -->
    <userUpdateOrgDialog v-if="showFormDiaUp" :pId="pId" :showFormDiaUp="showFormDiaUp" @refList="getTreen"
      @closeFormDiaoUp="closeFormDiaoUp" :titleUp="titleUp" />
  </div>
</template>
<script>
import userManage from '@/api/device/userManage.js'
import {
  TableMixin
} from '@/mixins/tableMixin'
import resourceManage from '@/api/device/resourceManage.js'
import {
  dragControllerDiv
} from '@/mixins/dragControllerDiv'
import userManageDialog from '@/views/Device/resourceManage/components/userManageDialog'
import dictUsers from '@/components/dict/DictSelectUtils.js'
import userOrgDialog from '@/views/Device/resourceManage/components/userOrgDialog.vue'
import userUpdateOrgDialog from '@/views/Device/resourceManage/components/userUpdateOrgDialog'

export default {
  name: 'UserManage',
  components: {
    userManageDialog,
    userOrgDialog,
    userUpdateOrgDialog //修改组织弹框
  },
  mixins: [TableMixin],
  data() {
    return {
      titles: '',
      titleUp: '',
      tableData: [],
      showFormDias: false,
      showFormDiaUp: false, //修改组织
      treeData: [],
      defaultProps: {
        children: 'children',
        label: 'companyName'
      },
      data: [],
      treeNode: {
        code: '',
        id: 0,
        companyName: '单位管理',
        type: 0,
        children: []
      },
      pId: '',
      url: {
        delete: '/device/base/user/'
      }, // 删除人员信息
      querys: [{
        group: 'main',
        operation: 'LIKE',
        parentGroup: '',
        property: 'name',
        relation: 'AND',
        value: ''
      },
      {
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'tel',
        relation: 'AND',
        value: ''
      },
      {
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'type',
        relation: 'AND',
        value: ''
      },
      {
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'companyId',
        relation: 'AND',
        value: ''
      }
      ],
      types: [] //人员类型
    }
  },
  watch: {
    filterText(val) {
      console.log(val)
      this.$refs.tree.filter(val)
    }
  },
  created() {
    this.types = dictUsers.getDictItemsFromCache('rylx')
  },
  mounted() {
    dragControllerDiv()
    this.getTreen()
  },
  methods: {
    // 组织树查询
    getTreen() {
      resourceManage.loadUnit({}, res => {
        this.treeData = res.rows
        this.$set(this.treeData)
      })
    },
    // renderContent(h, {node, data, store}) {
    //   return (
    //     <span
    //       class="custom-tree-node"
    //       on-mouseover={() => {
    //         this.show = true
    //       }}
    //       on-mouseout={() => {
    //         this.show = false
    //       }}
    //     >
    //       <span>{data.companyName}</span>
    //       <span>
    //         <el-popover placement="bottom" width="55" trigger="hover">
    //           <el-button
    //             v-show={data.id == 0}
    //             style="width:100%;border:0;margin:0;color:#606266;"
    //             size="mini"
    //             type="text"
    //             icon="el-icon-plus"
    //             on-click={() => this.append()}
    //           >
    //             新增
    //           </el-button>
    //           <el-button
    //             v-show={data.id}
    //             style="width:100%;border:0;margin:0;color:#606266;"
    //             size="mini"
    //             type="text"
    //             icon="el-icon-edit"
    //             on-click={() => this.upDateinfo(data, '')}
    //           >
    //             修改
    //           </el-button>
    //           <el-button
    //             v-show={data.id}
    //             style="width:100%;border:0;margin:0;color:#606266;"
    //             size="mini"
    //             icon="el-icon-delete"
    //             type="text"
    //             on-click={() => this.remove(data)}
    //           >
    //             删除
    //           </el-button>
    //           <i
    //             slot="reference"
    //             class="el-icon-more"
    //             style="font-size: 15px;"
    //           ></i>
    //         </el-popover>
    //       </span>
    //     </span>
    //   )
    // },
    reload() {
      this.treeData = [{
        code: '',
        id: 0,
        companyName: '单位管理',
        type: 0,
        children: []
      }]
      this.$set(this.treeData)
      this.loadData()
      this.getTreen()
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取人员信息
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      userManage.userQuery(this.queryParam).then(res => {
        // console.log(res)
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    handleAdd() {
      if (this.treeNode.type == 0) {
        this.$message.warning('请选择单位！')
        return
      }
      this.$refs.formModal.add(this.treeNode)
    },
    handleNodeClick(data) {
      this.treeNode = data
      if (data.id == '0') {
        this.querys[3].value = this.treeNode.id
        this.loadData(1)
      } else {
        this.querys[3].value = this.treeNode.id
        this.loadData(1)
      }
    },
    closeFormDiaos() {
      this.showFormDias = false
      this.getTreen()
      this.loadData()
    },
    // 删除单位信息
    remove(data) {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning'
      })
        .then(() => {
          userManage
            .removeUnits(data.id)
            .then(res => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000
                })
                this.queryParam.pageBean.page = 1
                this.loadData()
                this.getTreen()
                this.$set(this.treeData, this.treeData, this.treeData)
              }
            })
            .catch(res => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80
              })
            })
        })
        .catch(() => {
        })
    },
    // 修改单位信息
    closeFormDiaoUp() {
      this.showFormDiaUp = false
      this.getTreen()
      this.loadData()
    },
    append() {
      this.titles = '新增'
      this.showFormDias = true
    },
    upDateinfo(data, type) {
      this.titleUp = '修改'
      this.showFormDiaUp = true
      this.pId = data.id
    }
  }
}
</script>
<style lang="scss" scoped>
.common-tree-container {
  width: 100% !important;
}

.common-tree-container ::v-deep .el-tree {
  border: none;
}

::v-deep .custom-tree-node {
  span {
    font-size: 14PX !important;
  }
}

::v-deep .el-tree-node>.el-tree-node__children {
  overflow: visible;
}
</style>
